BlockingClient

Struct BlockingClient 

pub struct BlockingClient {
    pub proxy: Option<String>,
    pub timeout: Option<u64>,
    pub headers: HashMap<String, String>,
    pub max_retries: usize,
    /* private fields */
}

Fields

proxy: Option<String>

The proxy is ignored when targeting wasm32.

timeout: Option<u64>

Socket timeout.

headers: HashMap<String, String>

HTTP headers to set on every request made to Waterfalls server

max_retries: usize

Number of times to retry a request

Implementations

Source

impl BlockingClient

pub fn from_builder(builder: Builder) -> Self

Build a blocking client from a Builder

pub fn url(&self) -> &str

Get the underlying base URL.

pub fn get_request(&self, path: &str) -> Result<Request, Error>

Perform a raw HTTP GET request with the given URI path.

pub fn get_tx(&self, txid: &Txid) -> Result<Option<Transaction>, Error>

Get a Transaction option given its Txid

pub fn get_tx_no_opt(&self, txid: &Txid) -> Result<Transaction, Error>

Get a Transaction given its Txid.

pub fn waterfalls(&self, descriptor: &str) -> Result<WaterfallResponse, Error>

Query the waterfalls endpoint with a descriptor

pub fn waterfalls_addresses( &self, addresses: &[Address], ) -> Result<WaterfallResponse, Error>

Query the waterfalls endpoint with addresses

pub fn waterfalls_version( &self, descriptor: &str, version: u8, page: Option<u32>, to_index: Option<u32>, utxo_only: bool, ) -> Result<WaterfallResponse, Error>

Query waterfalls with version-specific parameters

pub fn get_header_by_hash( &self, block_hash: &BlockHash, ) -> Result<BlockHeader, Error>

Get a BlockHeader given a particular block hash.

pub fn server_recipient(&self) -> Result<String, Error>

Get the server’s public key for encryption

pub fn server_address(&self) -> Result<String, Error>

Get the server’s address for message signing verification

pub fn time_since_last_block(&self) -> Result<String, Error>

Get time since last block with freshness indicator

pub fn broadcast(&self, transaction: &Transaction) -> Result<(), Error>

Broadcast a Transaction to Waterfalls

pub fn get_tip_hash(&self) -> Result<BlockHash, Error>

Get the BlockHash of the current blockchain tip.

pub fn get_block_hash(&self, block_height: u32) -> Result<BlockHash, Error>

Get the BlockHash of a specific block height

pub fn get_address_txs(&self, address: &Address) -> Result<String, Error>

Get transaction history for the specified address in Esplora-compatible format